@@ -2,7 +2,7 @@ package App::PAUSE::Comaint;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use App::PAUSE::Comaint::PackageScanner;
 use WWW::Mechanize;
@@ -77,12 +77,9 @@ sub make_comaint {
     }
 
     if (keys %try) {
-        require PAUSE::Permissions;
-        my $perms = PAUSE::Permissions->new(preload => 1);
         my $msg = "You don't seem to be a primary maintainer of the following modules:\n";
         for my $module (sort keys %try) {
-            my $perm = $perms->module_permissions($module);
-            $msg .= sprintf "  %s (%s)\n", $module, $perm->owner;
+            $msg .= "  $module\n";
         }
         die $msg;
     }
